@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (C) 2002 - 2009 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (c) 2002-2015 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,6 +18,8 @@
 
 #include "costitem.h"
 
+#include <QObject>
+
 #include "tracedata.h"
 
 #define TRACE_DEBUG      0
@@ -424,13 +426,13 @@ void ProfileCostArray::addCost(ProfileCostArray* item)
     reserve(item->_count);
 
     if (item->_count < _count) {
-	for (i = 0; i<item->_count; i++)
+        for (i = 0; i<item->_count; ++i)
 	    _cost[i] += item->_cost[i];
     }
     else {
-	for (i = 0; i<_count; i++)
+        for (i = 0; i<_count; ++i)
 	    _cost[i] += item->_cost[i];
-	for (; i<item->_count; i++)
+        for (; i<item->_count; ++i)
 	    _cost[i] = item->_cost[i];
 	_count = item->_count;
     }
@@ -461,13 +463,13 @@ void ProfileCostArray::maxCost(ProfileCostArray* item)
     reserve(item->_count);
 
     if (item->_count < _count) {
-	for (i = 0; i<item->_count; i++)
+        for (i = 0; i<item->_count; ++i)
 	  if (_cost[i] < item->_cost[i]) _cost[i] = item->_cost[i];
     }
     else {
-	for (i = 0; i<_count; i++)
+        for (i = 0; i<_count; ++i)
 	  if (_cost[i] < item->_cost[i]) _cost[i] = item->_cost[i];
-	for (; i<item->_count; i++)
+        for (; i<item->_count; ++i)
 	    _cost[i] = item->_cost[i];
 	_count = item->_count;
     }
