@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (C) 2002-2008 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (c) 2002-2015 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -222,7 +222,7 @@ void GlobalConfig::readOptions()
     if (dirs.count()>0) _generalSourceDirs = dirs;
     count = sourceConfig->value("Count", 0).toInt();
     _objectSourceDirs.clear();
-    for (i=1;i<=count;i++) {
+    for(i=1; i<=count; ++i) {
 	QString n = sourceConfig->value(QString("Object%1").arg(i),
 					QString()).toString();
 	dirs = sourceConfig->value(QString("Dirs%1").arg(i),
