@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (C) 2007 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (c) 2007-2015 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -2341,7 +2341,7 @@ void CallGraphView::dotExited()
 			qDebug("  Edge with %d points:", points);
 
 		poly.resize(points);
-		for (i=0; i<points; i++) {
+                for (i=0; i<points; ++i) {
 			if (lineStream.atEnd())
 				break;
 			lineStream >> edgeX >> edgeY;
