@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (C) 2002, 2003 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (c) 2002-2015 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -441,7 +441,7 @@ void FunctionSelection::doUpdate(int changeType, bool)
         // need to disable sorting! Otherwise each change of shown cost
         // reorders list and changes order returned by topLevelItem()
         groupList->setSortingEnabled(false);
-        for (i=0; i<groupList->topLevelItemCount(); i++) {
+        for (i=0; i<groupList->topLevelItemCount(); ++i) {
             CostListItem* item = (CostListItem*) groupList->topLevelItem(i);
             item->setEventType(_eventType);
         }
